@@ -1,8 +1,7 @@
 package Lemonldap::NG::Manager::_i18n;
 
 use AutoLoader qw(AUTOLOAD);
-use UNIVERSAL qw(can);
-our $VERSION = '0.31';
+our $VERSION = '0.32';
 
 sub import {
     my ($caller_package) = caller;
@@ -38,7 +37,7 @@ sub en {
         applyConf                 => "Apply",
         areYouSure                => "Are you sure ?",
         authParams                => "Authentication Parameters",
-        authenticationType        => "Authentifition Type",
+        authenticationType        => "Authentication Type",
         canNotReadApplyConfFile   => "Configuration not applied: cannot read configuration file",
         changesAppliedLater       => 'Changes will be effective within 10 minutes. Use "apachectl reload" on concerned servers for immediate reloading',
         checkLogs                 => "Check Apache logs",
@@ -57,6 +56,7 @@ sub en {
         domain                    => "Domain",
         error                     => "Error",
         exportedVars              => "Exported Variables",
+        field                     => "Field",
         generalParameters         => "General Parameters",
         globalStorageOptions      => "Session Storage Parameters",
         group                     => "Group",
@@ -92,6 +92,7 @@ sub en {
         newVar                    => "New Variable",
         newVirtualHost            => "New Virtual Host",
         nextConf                  => "Next",
+        portal                    => "Portal",
         prevConf                  => "Previous",
         result                    => "Result",
         rule                      => "Rule",
@@ -106,6 +107,7 @@ sub en {
         unknownError              => "Unknown error",
         unknownErrorInVars        => "Unknown error in exported attributes",
         userGroups                => "User Groups",
+        value                     => "Value",
         virtualHosts              => "Virtual Hosts",
         waitingResult             => "Waiting result...",
         warningConfNotApplied     => "You have to reload handlers to take the saved configuration in account",
@@ -138,21 +140,22 @@ sub fr {
         domain                    => "Domaine",
         error                     => "Erreur",
         exportedVars              => "Attributs LDAP &agrave; exporter",
+        field                     => "Champ",
         generalParameters         => "Param&egrave;tres g&eacute;n&eacute;raux",
         globalStorageOptions      => "Param&egrave;tres du module Apache::Session",
         group                     => "Groupe",
         header                    => "En-t&ecirc;te",
         httpHeaders               => "En-t&ecirc;tes HTTP",
         invalidLine               => "Ligne invalide",
-        invalidVirtualHostName    => "Nom de d'hte virtuel incorrect",
-        invalidWhatToTrace        => "La donn&eacute;e &agrave; inscrire dans les journaux ne peut contenir qu'un attribut export ou une macro",
+        invalidVirtualHostName    => "Nom de d'h&ocirc;te virtuel incorrect",
+        invalidWhatToTrace        => "La donn&eacute;e &agrave; inscrire dans les journaux ne peut contenir qu'un attribut export&eacute; ou une macro",
         isNotANumber              => "n'est pas un nombre",
         isNotAValidAttributeName  => "n'est pas un nom d'attribut valide",
         isNotAValidCookieName     => "n'est pas un nom de cookie valide",
         isNotAValidDomainName     => "n'est pas un nom de domaine valide",
         isNotAValidGroupName      => "n'est pas un nom de groupe valide",
         isNotAValidHTTPHeaderName => "n'est pas un nom d'en-t&ecirc;te HTTP valide",
-        isNotAValidLDAPAttributeName => "is not a valid LDAP attribute name",
+        isNotAValidLDAPAttributeName => "n'est pas un nom d'attribut LDAP valide",
         isNotAValidMacroName      => "n'est pas un nom de macro valide",
         isNotAValidVirtualHostName => "n'est pas un nom d'h&ocirc;te virtuel valide",
         lastConf                  => "Derni&egrave;re",
@@ -171,8 +174,9 @@ sub fr {
         newMacro                  => "Nouvelle macro",
         newRule                   => "Nouvelle r&egrave;gle",
         newVar                    => "Nouvelle variable",
-        newVirtualHost            => "Nouvel hote virtuel",
+        newVirtualHost            => "Nouvel h&ocirc;te virtuel",
         nextConf                  => "Suivante",
+        portal                    => "Portail",
         prevConf                  => "Pr&eacute;c&eacute;dente",
         result                    => "R&eacute;sultat",
         rule                      => "R&egrave;gle",
@@ -181,12 +185,13 @@ sub fr {
         saveFailure               => "&Eacute;chec de la sauvegarde",
         securedCookie             => "Cookie s&eacute;curis&eacute; (SSL)",
         sessionStorage            => "Stockage des sessions",
-        sessionTimeout            => "Dure de vie des sessions",
+        sessionTimeout            => "Dur&eacute;e de vie des sessions",
         syntaxError               => "Erreur de syntaxe",
         unableToSave              => "Votre navigateur ne supporte pas les objets XMLHTTPRequest: sauvegarde impossible.",
         unknownError              => "Erreur inconnue",
         unknownErrorInVars        => "Erreur inconnue dans les attributs export&eacute;s",
         userGroups                => "Groupes d'utilisateurs",
+        value                     => "Valeur",
         virtualHosts              => "H&ocirc;tes virtuels",
         waitingResult             => "En attente...",
         warningConfNotApplied     => "Vous devez recharger les agents pour que la configuration sauvegard&eacute;e soit appliqu&eacute;e",
